% a server to transfer 
clear all
close all

%% gcmfaces environmental variables
global lat lon
global x y

load_global_variables_fast;

% load regrid variables
global lat_index lon_index wgt_factor
lat_index = read2memory('lat_index_90x1170_to_72x46.llc90.bin',[90 1170]);
lon_index = read2memory('lon_index_90x1170_to_72x46.llc90.bin',[90 1170]);
wgt_factor = read2memory('wgt_factor_90x1170_to_72x46.llc90.bin',[90 1170]);

%% interpolate 4x5->90x1170
%folder locations
CPL_ROOT = '/data/home/yxzhang/AtmSoilOcean';
GCOUT = [CPL_ROOT '/GEOS-Chem/run.geos5.4x5.hg.online/GC_OUT/'];
MGIN = [CPL_ROOT '/MITgcm/verification/global_hg_llc90/run/MG_IN/'];

%archive folders
GCOUTa = [CPL_ROOT '/GEOS-Chem/run.geos5.4x5.hg.online/GC_OUTa/'];
MGINa = [CPL_ROOT '/MITgcm/verification/global_hg_llc90/run/MG_INa/'];

step_lag = 140243; 
% for 20080101, GC is step 1, but MG is 140244

while(1)
    % Hg0Atm
	% get the file lists of GCOUT
  filelist_gcout = dir_date(strcat(GCOUT,'Hg0Atm.*'));
	% get the file lists of MGIN
	filelist_mgin = dir_date(strcat(MGIN,'Hg0Atm.*.ready'));

	n_file_gcout = numel(filelist_gcout);
	n_file_mgin = numel(filelist_mgin);
	if n_file_gcout > n_file_mgin
		for i = n_file_mgin+1 : n_file_gcout
			filename = filelist_gcout(i).name;
			GC_step = str2double(filename(8:end));
			MG_step = GC_step + step_lag;
			filename_new = strcat(filename(1:7),sprintf('%010d',str2double(filename(8:end))+step_lag));
			
			% two chances to read data

			count = 0;
      err_count = 0;
      while count == err_count
				try
					datain = pos(load(strcat(GCOUT,filename))');
					datain = [datain; datain(1,:)];
					dataout = interp2(lat,lon,datain,y,x);
				catch
					err_count = err_count + 1;
				end
				count = count + 1;

			end

      % safety
      dataout(isnan(dataout) | isinf(dataout) | dataout < 0) = 0;

			write2file(strcat(MGIN,filename_new),dataout);	
      fid = fopen(strcat(MGIN,filename_new,'.ready'),'w');   
			fclose(fid);	
      disp([filename '=>' filename_new]);
		end

		% do relocate
		for i = 1:n_file_mgin
			filename = filelist_gcout(i).name;
			filename_new = strcat(filename(1:7),sprintf('%010d',str2double(filename(8:end))+step_lag));
			movefile(strcat(GCOUT,filename),strcat(GCOUTa,filename));
			movefile(strcat(MGIN,filename_new),strcat(MGINa,filename_new));
			movefile(strcat(MGIN,filename_new,'.ready'),strcat(MGINa,filename_new,'.ready'));
		end

	end

    % Hg2Dep
	% get the file lists of GCOUT
  filelist_gcout = dir_date(strcat(GCOUT,'HgWDep.*'));
	% get the file lists of MGIN
	filelist_mgin = dir_date(strcat(MGIN,'Hg2Dep.*.ready'));

	n_file_gcout = numel(filelist_gcout);
	n_file_mgin = numel(filelist_mgin);
	if n_file_gcout > n_file_mgin
		for i = n_file_mgin+1 : n_file_gcout
			filename2 = filelist_gcout(i).name;            % WDep
			filename1 = filename2;  filename1(3) = 'D';    % DDep
			
			GC_step = str2double(filename1(8:end));
			MG_step = GC_step + step_lag;
			filename_new = strcat('Hg2Dep.',sprintf('%010d',str2double(filename1(8:end))+step_lag));
			

			count = 0;
      err_count = 0;
      while count == err_count
				try
					datain1 = pos(load(strcat(GCOUT,filename1))');  % Dry
					datain2 = pos(load(strcat(GCOUT,filename2))');  % Wet
			    % scale dry
			    datain = [datain1; datain1(1,:)];
			    dataout1 = interp2(lat,lon,datain,y,x);
			    		
			    % scale wet
			       datain = [datain2; datain2(1,:)];
			       dataout2 = interp2(lat,lon,datain,y,x);				   
				
                                catch
					err_count = err_count + 1;
				end
				count = count + 1;

			end			

      % safety
      dataout1(isnan(dataout1) | isinf(dataout1) | dataout1 < 0) = 0;
      dataout2(isnan(dataout2) | isinf(dataout2) | dataout2 < 0) = 0;

			write2file(strcat(MGIN,filename_new),dataout1+dataout2);	
      fid = fopen(strcat(MGIN,filename_new,'.ready'),'w');   
			fclose(fid);
      disp([filename1 '+' filename2 '=>' filename_new]);	
		end

		% do relocate
		for i = 1:n_file_mgin
			filename2 = filelist_gcout(i).name;
			filename_new = strcat('Hg2Dep.',sprintf('%010d',str2double(filename2(8:end))+step_lag));
			filename1 = filename2;  filename1(3) = 'D';		
			
			movefile(strcat(GCOUT,filename1),strcat(GCOUTa,filename1));  
			movefile(strcat(GCOUT,filename2),strcat(GCOUTa,filename2));                     
			movefile(strcat(MGIN,filename_new),strcat(MGINa,filename_new));
			movefile(strcat(MGIN,filename_new,'.ready'),strcat(MGINa,filename_new,'.ready'));
		end
	end
	

end

